/*
 * Copyright (c) 2016 Intel Corporation
 *
 * SPDX-License-Identifier: Apache-2.0
 */

#include <zephyr/kernel.h>
#include <zephyr/drivers/gpio.h>

/* 1000 msec = 1 sec */
#define SLEEP_TIME_MS   1000

/* The devicetree node identifier for the "led0" alias. */
#define LED0_NODE DT_ALIAS(led0)
#define LED1_NODE DT_ALIAS(led1)
#define LED2_NODE DT_ALIAS(led2)
#define OUT0_NODE DT_ALIAS(out0)

/*
 * A build error on this line means your board is unsupported.
 * See the sample documentation for information on how to fix this.
 */
static const struct gpio_dt_spec led00 = GPIO_DT_SPEC_GET(LED2_NODE, gpios);
static const struct gpio_dt_spec led01 = GPIO_DT_SPEC_GET(LED1_NODE, gpios);
static const struct gpio_dt_spec led02 = GPIO_DT_SPEC_GET(LED0_NODE, gpios);
static const struct gpio_dt_spec out00 = GPIO_DT_SPEC_GET(OUT0_NODE, gpios);

void main(void)
{
	int ret;

	if (!gpio_is_ready_dt(&led00)) {
		return;
	}

	if (!gpio_is_ready_dt(&led01)) {
		return;
	}

	if (!gpio_is_ready_dt(&led02)) {
		return;
	}

	ret = gpio_pin_configure_dt(&led00, GPIO_OUTPUT_ACTIVE);
	if (ret < 0) {
		return;
	}

	ret = gpio_pin_configure_dt(&led01, GPIO_OUTPUT_ACTIVE);
	if (ret < 0) {
		return;
	}

	ret = gpio_pin_configure_dt(&led02, GPIO_OUTPUT_ACTIVE);
	if (ret < 0) {
		return;
	}

	while (1) {
		ret = gpio_pin_toggle_dt(&led00);
		if (ret < 0) {
			return;
		}

		ret = gpio_pin_toggle_dt(&led01);
		if (ret < 0) {
			return;
		}

		ret = gpio_pin_toggle_dt(&led02);
		if (ret < 0) {
			return;
		}
		k_msleep(SLEEP_TIME_MS);
	}
}
